@@ -10,8 +10,9 @@ use Data::Dumper;
 use Sys::Hostname;
 use Plack::Util;
 use Class::Inspector;
+use Scalar::Util qw(blessed);
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 # Basic attributes
 attr -host => hostname;
@@ -260,13 +261,25 @@ sub psgi {
         $self->finalize;
     }
     catch {
-        my $message = $self->long_error ? longmess($_) : $_;
+        my $exception = $_;
+        my $res = $self->res;
 
-        # Log error
-        $self->logger( 'critical', $message ) if $self->can('logger');
+        if (blessed $exception && $exception->isa('Kelp::Exception')) {
+            # No logging here, since it is a message for the user with a code
+            # rather than a real exceptional case
+            # (Nothing really broke, user code invoked this)
 
-        # Render 500
-        $self->res->render_500($_);
+            $res->render_exception($exception);
+        }
+        else {
+            my $message = $self->long_error ? longmess($exception) : $exception;
+
+            # Log error
+            $self->logger( 'critical', $message ) if $self->can('logger');
+
+            # Render 500
+            $res->render_500($_);
+        }
         $self->finalize;
     };
 }
